curver: For calculations in the curve complex
=============================================

Description
-----------

For calculations in the curve complex

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/curver/
